@@ -34,21 +34,17 @@ class EnhancedJSONEncoder(json.JSONEncoder):
         if isinstance(o, ReprInDumps):
             return o.__repr_in_dumps__()
         if isinstance(o, type):
-            return o.__name__
+            return {'_t': 'PY::class', 'key': o.__qualname__}
         if is_dataclass(o):
-            # d = asdict(o)
-            d = {}
-            dataclass_fields = get_dataclass_field_name_to_field(type(o), with_init_vars=False)
-            for key in dataclass_fields:
-                descriptor: Field = dataclass_fields[key]
-                if descriptor.repr:
-                    d[key] = getattr(o, key)
-            return d
+            return {
+                key: getattr(o, key)
+                for key, field in get_dataclass_field_name_to_field(type(o), with_init_vars=False).items()
+                if field.repr
+            }
         if isinstance(o, datetime.datetime):
-            return int(o.timestamp() * 1000)
-        if isinstance(o, datetime.date):
-            return o.isoformat()
-        if isinstance(o, datetime.time):
+            if o.tzinfo is None or o.tzinfo.utcoffset(o) is None:  # PROHIBIT naive datetime serialisation
+                raise TypeError("TypeError: datetime.datetime WITHOUT tzinfo is not JSON serializable")
+        if isinstance(o, datetime.date | datetime.time):  # date or time or datetime
             return o.isoformat()
         if isinstance(o, set):
             return list(o)
@@ -57,7 +53,7 @@ class EnhancedJSONEncoder(json.JSONEncoder):
         if isinstance(o, Decimal):
             return str(o)
         if isinstance(o, Exception):
-            return repr(o)
+            return {'_t': 'PY::Exception', 'key': type(o).__qualname__, 'args': o.args}
         return super().default(o)
 
 
